---
url: https://www.normattiva.it/uri-res/N2Ls?urn:nir:stato:decreto.legislativo:2015-08-05;127
url_xml: https://www.normattiva.it/do/atto/caricaAKN?dataGU=20150818&codiceRedaz=15G00143&dataVigenza=20251104
dataGU: 20150818
codiceRedaz: 15G00143
dataVigenza: 20251104
---

# Trasmissione telematica delle operazioni IVA e di controllo delle cessioni di beni effettuate attraverso distributori automatici, in attuazione dell'articolo 9, comma 1, lettere d) e g), della legge 11 marzo 2014, n. 23. (15G00143)

IL PRESIDENTE DELLA REPUBBLICA

Visti gli articoli 76 e 87 della Costituzione;

Vista la legge 11 marzo 2014, n. 23, con la quale e' stata conferita delega al Governo recante disposizioni per un sistema fiscale piu' equo, trasparente e orientato alla crescita e, in particolare, l'articolo 9, comma 1, lettera d), con il quale il Governo e' delegato a introdurre norme per incentivare, mediante una riduzione degli adempimenti amministrativi e contabili a carico dei contribuenti, l'utilizzo della fatturazione elettronica e la trasmissione telematica dei corrispettivi, nonche' di adeguati meccanismi di riscontro tra la documentazione in materia di imposta sul valore aggiunto (IVA) e le transazioni effettuate, potenziando i relativi sistemi di tracciabilita' dei pagamenti, e l'articolo 9, comma 1, lettera g), con il quale il Governo e' delegato a prevedere specifici strumenti di controllo relativamente alle cessioni di beni effettuate attraverso distributori automatici;

Vista la preliminare deliberazione del Consiglio dei ministri, adottata nella riunione del 21 aprile 2015;

Acquisiti i pareri delle Commissioni parlamentari competenti per materia e per i profili di carattere finanziario della Camera dei deputati e del Senato della Repubblica;

Visto l'articolo 1, comma 7, della citata legge n. 23 del 2014, secondo cui qualora il Governo non intenda conformarsi ai pareri parlamentari, trasmette nuovamente i testi alle Camere;

Vista la preliminare deliberazione del Consiglio dei ministri, adottata nella riunione del 17 luglio 2015;

Acquisiti i pareri definitivi delle competenti Commissioni parlamentari ai sensi dell'articolo 1, comma 7, della citata legge n. 23 del 2014;

Vista la deliberazione del Consiglio dei ministri, adottata nella riunione del 31 luglio 2015;

Sulla proposta del Ministro dell'economia e delle finanze;

Emana il seguente decreto legislativo:

## Art. 1. - Fatturazione elettronica e trasmissione telematica delle fatture o dei relativi dati

1. A decorrere dal 1° luglio 2016, l'Agenzia delle entrate mette a disposizione dei contribuenti, gratuitamente, un servizio per la generazione, la trasmissione e la conservazione delle fatture elettroniche. PERIODO SOPPRESSO DALLA L. 27 DICEMBRE 2017, N. 205. (3)(4)

2. A decorrere dal 1° gennaio 2017, il Ministero dell'economia e delle finanze mette a disposizione dei soggetti passivi dell'imposta sul valore aggiunto il Sistema di Interscambio di cui all'articolo 1, commi 211 e 212, della legge 24 dicembre 2007, n. 244, gestito dall'Agenzia delle entrate anche per l'acquisizione dei dati fiscalmente rilevanti, ai fini della trasmissione e della ricezione delle fatture elettroniche, e di eventuali variazioni delle stesse, relative a operazioni che intercorrono tra soggetti residenti o stabiliti nel territorio dello Stato, secondo il formato della fattura elettronica di cui all'allegato A del decreto del Ministro dell'economia e delle finanze, di concerto con il Ministro per la pubblica amministrazione e la semplificazione, 3 aprile 2013, n. 55. A decorrere dalla data di cui al periodo precedente, l'Agenzia delle entrate mette a disposizione del contribuente, mediante l'utilizzo di reti telematiche e anche in formato strutturato, le informazioni acquisite. (3) (4)

3. Al fine di razionalizzare il procedimento di fatturazione e registrazione, per le cessioni di beni e le prestazioni di servizi effettuate tra soggetti residenti o stabiliti nel territorio dello Stato, e per le relative variazioni, sono emesse esclusivamente fatture elettroniche utilizzando il Sistema di Interscambio e secondo il formato di cui al comma 2. Gli operatori economici possono avvalersi, attraverso accordi tra le parti, di intermediari per la trasmissione delle fatture elettroniche al Sistema di Interscambio, ferme restando le responsabilita' del soggetto che effettua la cessione del bene o la prestazione del servizio. Con il medesimo decreto ministeriale di cui al comma 2 potranno essere individuati ulteriori formati della fattura elettronica basati su standard o norme riconosciuti nell'ambito dell'Unione europea. Le fatture elettroniche emesse nei confronti dei consumatori finali sono rese disponibili a questi ultimi dai servizi telematici dell'Agenzia delle entrate; una copia della fattura elettronica ovvero in formato analogico sara' messa a disposizione direttamente da chi emette la fattura. E' comunque facolta' dei consumatori rinunciare alla copia elettronica o in formato analogico della fattura. PERIODO SOPPRESSO DAL D.L. 30 APRILE 2022, N. 36. PERIODO SOPPRESSO DAL D.L. 30 APRILE 2022, N. 36. (3) (4) (19)

3-bis. I soggetti passivi di cui al comma 3 trasmettono telematicamente all'Agenzia delle entrate i dati relativi alle operazioni di cessione di beni e di prestazione di servizi effettuate e ricevute verso e da soggetti non stabiliti nel territorio dello Stato, salvo quelle per le quali e' stata emessa una bolletta doganale, quelle per le quali siano state emesse o ricevute fatture elettroniche secondo le modalita' indicate nel comma 3, nonche' quelle, purche' di importo non superiore ad euro 5.000 per ogni singola operazione, relative ad acquisti di beni e servizi non rilevanti territorialmente ai fini IVA in Italia ai sensi degli articoli da 7 a 7-octies del decreto del Presidente della Repubblica 26 ottobre 1972, n. 633. La trasmissione telematica e' effettuata trimestralmente entro la fine del mese successivo al trimestre di riferimento. Con riferimento alle operazioni effettuate a partire dal 1° luglio 2022, i dati di cui al primo periodo sono trasmessi telematicamente utilizzando il Sistema di interscambio secondo il formato di cui al comma 2. Con riferimento alle medesime operazioni:

- a) la trasmissione telematica dei dati relativi alle operazioni svolte nei confronti di soggetti non stabiliti nel territorio dello Stato e' effettuata entro i termini di emissione delle fatture o dei documenti che ne certificano i corrispettivi;
- b) la trasmissione telematica dei dati relativi alle operazioni ricevute da soggetti non stabiliti nel territorio dello Stato e' effettuata entro il quindicesimo giorno del mese successivo a quello di ricevimento del documento comprovante l'operazione o di effettuazione dell'operazione.

3-ter. I soggetti obbligati alla comunicazione dei dati delle fatture emesse e ricevute ai sensi del comma 3 del presente articolo sono esonerati dall'obbligo di annotazione in apposito registro, di cui agli articoli 23 e 25 del decreto del Presidente della Repubblica 26 ottobre 1972, n. 633.

4. COMMA ABROGATO DALLA L. 27 DICEMBRE 2017, N. 205. (3) (4)

5. Con decreto del Ministro dell'economia e delle finanze, da emanarsi entro sei mesi dalla data di entrata in vigore del presente decreto, sono stabilite nuove modalita' semplificate di controlli a distanza degli elementi acquisiti dall'Agenzia delle entrate ai sensi dei commi 3 e 3-bis, basate sul riscontro tra i dati comunicati dai soggetti passivi dell'imposta sul valore aggiunto e le transazioni effettuate, tali da ridurre gli adempimenti di tali soggetti, non ostacolare il normale svolgimento dell'attivita' economica degli stessi ed escludere la duplicazione di attivita' conoscitiva. (3) (4)

5-bis. I file delle fatture elettroniche acquisiti ai sensi del comma 3 sono memorizzati fino al 31 dicembre dell'ottavo anno successivo a quello di presentazione della dichiarazione di riferimento ovvero fino alla definizione di eventuali giudizi, al fine di essere utilizzati:

- a) dalla Guardia di finanza nell'assolvimento delle funzioni di polizia economica e finanziaria di cui all'articolo 2, comma 2, del decreto legislativo 19 marzo 2001, n. 68;
- b) dall'Agenzia delle entrate e dalla Guardia di Finanza per le attivita' di analisi del rischio e di controllo a fini fiscali.
- b-bis) ((dall'Agenzia delle dogane e dei monopoli per le attivita' di vigilanza e di controllo di cui all'articolo 18 del testo unico delle disposizioni legislative concernenti le imposte sulla produzione e sui consumi e relative sanzioni penali e amministrative, di cui al decreto legislativo 26 ottobre 1995, n. 504)).

5-ter. Ai fini di cui al comma 5-bis, la Guardia di Finanza ((, l'Agenzia delle entrate nonche' l'Agenzia delle dogane e dei monopoli)), sentito il Garante per la protezione dei dati personali, adottano idonee misure di garanzia a tutela dei diritti e delle liberta' degli interessati, attraverso la previsione di apposite misure di sicurezza, anche di carattere organizzativo, in conformita' con le disposizioni del regolamento (UE) 2016/679 del Parlamento Europeo e del Consiglio del 27 aprile 2016 e del decreto legislativo 30 giugno 2003, n. 196.

5-quater. Per la fatturazione elettronica e per la memorizzazione, conservazione e consultazione delle fatture elettroniche relative alle cessioni di beni e alle prestazioni di servizi destinate agli organismi di cui agli articoli 4, 6 e 7 della legge 3 agosto 2007, n. 124, resta fermo quanto previsto ai sensi dell'articolo 29 della medesima legge.

6. In caso di emissione di fattura, tra soggetti residenti o stabiliti nel territorio dello Stato, con modalita' diverse da quelle previste dal comma 3, la fattura si intende non emessa e si applicano le sanzioni previste dall'articolo 6 del decreto legislativo 18 dicembre 1997, n. 471. Il cessionario e il committente, per non incorrere nella sanzione di cui all'articolo 6, comma 8, del decreto legislativo 18 dicembre 1997, n. 471, devono adempiere agli obblighi documentali ivi previsti mediante il Sistema di Interscambio. Per il primo semestre del periodo d'imposta 2019 le sanzioni di cui ai periodi precedenti:

- a) non si applicano se la fattura e' emessa con le modalita' di cui al comma 3 entro il termine di effettuazione della liquidazione periodica dell'imposta sul valore aggiunto ai sensi dell'articolo 1, comma 1, del decreto del Presidente della Repubblica 23 marzo 1998, n. 100;
- b) si applicano con riduzione dell'80 per cento a condizione che la fattura elettronica sia emessa entro il termine di effettuazione della liquidazione dell'imposta sul valore aggiunto del periodo successivo. Per i contribuenti che effettuano la liquidazione periodica dell'imposta sul valore aggiunto con cadenza mensile le disposizioni di cui al periodo precedente si applicano fino al 30 settembre 2019. In caso di omissione della trasmissione di cui al comma 3-bis ovvero di trasmissione di dati incompleti o inesatti, si applica la sanzione di cui all'articolo 11, comma 2-quater, del decreto legislativo 18 dicembre 1997, n. 471. (3)(4)

6-bis. Gli obblighi di conservazione previsti dall'articolo 3 del decreto del Ministro dell'economia e delle finanze 17 giugno 2014, pubblicato nella Gazzetta Ufficiale n. 146 del 26 giugno 2014, si intendono soddisfatti per tutte le fatture elettroniche nonche' per tutti i documenti informatici trasmessi attraverso il Sistema di Interscambio di cui all'articolo 1, comma 211, della legge 24 dicembre 2007, n. 244, e memorizzati dall'Agenzia delle entrate. Per il servizio di conservazione gratuito delle fatture elettroniche di cui al presente articolo, reso disponibile agli operatori IVA dall'Agenzia delle entrate, il partner tecnologico Sogei S.p.a. non puo' avvalersi di soggetti terzi. I tempi e le modalita' di applicazione della presente disposizione, anche in relazione agli obblighi contenuti nell'articolo 5 del citato decreto ministeriale 17 giugno 2014, sono stabiliti con apposito provvedimento del direttore dell'Agenzia delle entrate. Con provvedimento del direttore dell'Agenzia delle dogane e dei monopoli sono altresi' stabilite le modalita' di conservazione degli scontrini delle giocate dei giochi pubblici autorizzati, secondo criteri di semplificazione e attenuazione degli oneri di gestione per gli operatori interessati e per l'amministrazione, anche con il ricorso ad adeguati strumenti tecnologici, ferme restando le esigenze di controllo dell'amministrazione finanziaria. (3) (4)

6-ter. Con provvedimento del direttore dell'Agenzia delle entrate sono emanate le ulteriori disposizioni necessarie per l'attuazione del presente articolo. (3) (4)

6-quater. Al fine di preservare i servizi di pubblica utilita', con provvedimento del direttore dell'Agenzia delle entrate sono definite le regole tecniche per l'emissione delle fatture elettroniche tramite il Sistema di interscambio da parte dei soggetti passivi dell'IVA che offrono i servizi disciplinati dai regolamenti di cui ai decreti del Ministro delle finanze 24 ottobre 2000, n. 366, e 24 ottobre 2000, n. 370, nei confronti dei soggetti persone fisiche che non operano nell'ambito di attivita' d'impresa, arte e professione. Le predette regole tecniche valgono esclusivamente per le fatture elettroniche emesse nei confronti dei consumatori finali con i quali sono stati stipulati contratti prima del 1° gennaio 2005 e dei quali non e' stato possibile identificare il codice fiscale anche a seguito dell'utilizzo dei servizi di verifica offerti dall'Agenzia delle entrate.

--------------- AGGIORNAMENTO (3) La L. 27 dicembre 2017, n. 205 ha disposto (con l'art. 1, comma 916) che le presenti modifiche si applicano alle fatture emesse a partire dal 1º gennaio 2019. Ha inoltre disposto (con l'art. 1, comma 917, lettere a) e b)) che "Fermo restando quanto previsto al comma 916, le disposizioni dei commi da 909 a 928 si applicano alle fatture emesse a partire dal 1º luglio 2018 relative a: a) cessioni di benzina o di gasolio destinati ad essere utilizzati come carburanti per motori; b) prestazioni rese da soggetti subappaltatori e subcontraenti della filiera delle imprese nel quadro di un contratto di appalto di lavori, servizi o forniture stipulato con un'amministrazione pubblica. Ai fini della presente lettera, per filiera delle imprese si intende l'insieme dei soggetti, destinatari della normativa di cui all'articolo 3 della legge 13 agosto 2010, n. 136, che intervengono a qualunque titolo nel ciclo di realizzazione del contratto, anche con noli e forniture di beni e prestazioni di servizi, ivi compresi quelli di natura intellettuale, qualunque sia l'importo dei relativi contratti o dei subcontratti. Le fatture elettroniche emesse ai sensi della presente lettera riportano gli stessi codici CUP e CIG di cui all'articolo 25, comma 2, del decreto-legge 24 aprile 2014, n. 66, convertito, con modificazioni, dalla legge 23 giugno 2014, n. 89, riportati nelle fatture emesse dall'impresa capofila nei confronti dell'amministrazione pubblica". --------------- AGGIORNAMENTO (4) L. 27 dicembre 2017, n. 205, come modificata dal D.L. 12 luglio 2018, n. 87, convertito con modificazioni dalla L. 9 agosto 2018, n. 96, ha disposto (con l'art. 1, comma 917, lettera a)) che "Fermo restando quanto previsto al comma 916, le disposizioni dei commi da 909 a 928 si applicano alle fatture emesse a partire dal 1º luglio 2018 relative a: a) cessioni di benzina o di gasolio destinati ad essere utilizzati come carburanti per motori, ad eccezione delle cessioni di carburante per autotrazione presso gli impianti stradali di distribuzione, per le quali il comma 920 si applica dal 1° gennaio 2019". --------------- AGGIORNAMENTO (19) Il D.L. 30 aprile 2022, n. 36 ha disposto (con l'art. 18, comma 3) che la modifica di cui al comma 3 del presente articolo "si applica a partire dal 1° luglio 2022 per i soggetti che nell'anno precedente abbiano conseguito ricavi ovvero percepito compensi, ragguagliati ad anno, superiori a euro 25.000, e a partire dal 1° gennaio 2024 per i restanti soggetti. Per il terzo trimestre del periodo d'imposta 2022, le sanzioni di cui all'articolo 6, comma 2, del decreto legislativo 18 dicembre 1997, n. 471, non si applicano ai soggetti ai quali l'obbligo di fatturazione elettronica e' esteso a decorrere dal 1° luglio 2022, se la fattura elettronica e' emessa entro il mese successivo a quello di effettuazione dell'operazione".

## Art. 2. - Trasmissione telematica dei dati dei corrispettivi

1. A decorrere dal 1° gennaio 2020 i soggetti che effettuano le operazioni di cui all'articolo 22 del decreto del Presidente della Repubblica 26 ottobre 1972, n. 633, memorizzano elettronicamente e trasmettono telematicamente all'Agenzia delle entrate i dati relativi ai corrispettivi giornalieri. La memorizzazione elettronica e la connessa trasmissione dei dati dei corrispettivi sostituiscono gli obblighi di registrazione di cui all'articolo 24, primo comma, del suddetto decreto n. 633 del 1972. Le disposizioni di cui ai periodi precedenti si applicano a decorrere dal 1° luglio 2019 ai soggetti con un volume d'affari superiore ad euro 400.000. Per il periodo d'imposta 2019 restano valide le opzioni per la memorizzazione elettronica e la trasmissione telematica dei dati dei corrispettivi esercitate entro il 31 dicembre 2018. Con decreto del Ministro dell'economia e delle finanze, possono essere previsti specifici esoneri dagli adempimenti di cui al presente comma in ragione della tipologia di attivita' esercitata.

1-bis. A decorrere dal 1º luglio 2018, la memorizzazione elettronica e la trasmissione telematica dei dati dei corrispettivi di cui al comma 1 sono obbligatorie con riferimento alle cessioni di benzina o di gasolio destinati ad essere utilizzati come carburanti per motori. Con provvedimento del direttore dell'Agenzia delle entrate, d'intesa con il direttore dell'Agenzia delle dogane e dei monopoli, sentito il Ministero dello sviluppo economico, sono definiti, anche al fine di semplificare gli adempimenti amministrativi dei contribuenti, le informazioni da trasmettere, le regole tecniche, i termini per la trasmissione telematica e le modalita' con cui garantire la sicurezza e l'inalterabilita' dei dati. Con il medesimo provvedimento possono essere definiti modalita' e termini graduali per l'adempimento dell'obbligo di memorizzazione elettronica e trasmissione telematica dei dati dei corrispettivi, anche in considerazione del grado di automazione degli impianti di distribuzione di carburanti. (3) (4)

1-ter. ((In considerazione delle peculiarita' tecniche e regolamentari che caratterizzano la ricarica elettrica dei veicoli tramite stazioni di ricarica di cui al regolamento (UE) 2023/1804 del Parlamento europeo e del Consiglio del 13 settembre 2023, con provvedimento del direttore dell'Agenzia delle entrate sono definite le informazioni da trasmettere, le regole tecniche, i termini per la memorizzazione elettronica e la trasmissione telematica dei dati dei corrispettivi di cui al comma 1, nonche' le modalita' con cui garantire la sicurezza e l'inalterabilita' dei dati.))

2. A decorrere dal 1° aprile 2017, la memorizzazione elettronica e la trasmissione telematica dei dati dei corrispettivi di cui al comma 1 sono obbligatorie per i soggetti passivi che effettuano cessioni di beni o prestazioni di servizi tramite distributori automatici. Al fine dell'assolvimento dell'obbligo di cui al precedente periodo, nel provvedimento del direttore dell'Agenzia delle entrate di cui al comma 4, sono indicate soluzioni che consentano di non incidere sull'attuale funzionamento degli apparecchi distributori e garantiscano, nel rispetto dei normali tempi di obsolescenza e rinnovo degli stessi, la sicurezza e l'inalterabilita' dei dati dei corrispettivi acquisiti dagli operatori. Con provvedimento del direttore dell'Agenzia delle entrate possono essere stabiliti termini differiti, rispetto al 1° aprile 2017, di entrata in vigore dell'obbligo di memorizzazione elettronica e trasmissione telematica dei dati dei corrispettivi, in relazione alle specifiche variabili tecniche di peculiari distributori automatici.

3. La memorizzazione elettronica e la trasmissione telematica di cui al comma 1 sono effettuate mediante strumenti tecnologici che garantiscano l'inalterabilita' e la sicurezza dei dati nonche' la piena integrazione e interazione del processo di registrazione dei corrispettivi con il processo di pagamento elettronico. A tale fine, lo strumento hardware o software mediante il quale sono accettati i pagamenti elettronici e' sempre collegato allo strumento mediante il quale sono registrati e memorizzati, in modo puntuale, e trasmessi, in forma aggregata, i dati dei corrispettivi nonche' i dati dei pagamenti elettronici giornalieri. (24)

4. Con provvedimento del Direttore dell'Agenzia delle entrate, sentite le associazioni di categoria nell'ambito di forum nazionali sulla fatturazione elettronica istituiti in base alla decisione della Commissione europea COM (2010) 8467, sono definite le informazioni da trasmettere, le regole tecniche, i termini per la trasmissione telematica e le caratteristiche tecniche degli strumenti di cui al comma 3. Con lo stesso provvedimento sono approvati i relativi modelli e ogni altra disposizione necessaria per l'attuazione delle disposizioni di cui ai commi 1 e 2.

5. La memorizzazione elettronica e la trasmissione telematica di cui ai commi 1 e 2 sostituiscono la modalita' di assolvimento dell'obbligo di certificazione fiscale dei corrispettivi di cui all'articolo 12, comma 1, della legge 30 dicembre 1991, n. 413, e al decreto del Presidente della Repubblica 21 dicembre 1996, n. 696. Resta comunque fermo l'obbligo di emissione della fattura su richiesta del cliente. Con decreto del Ministro dell'economia e delle finanze, di concerto con il Ministro dello sviluppo economico possono essere individuate tipologie di documentazione idonee a rappresentare, anche ai fini commerciali, le operazioni. La memorizzazione elettronica di cui ai commi 1 e 2 e, a richiesta del cliente, la consegna dei documenti di cui ai periodi precedenti, e' effettuata non oltre il momento dell'ultimazione dell'operazione.

5-bis. A decorrere dal 1° luglio 2022, i soggetti che effettuano le operazioni di cui all'articolo 22 del decreto del Presidente della Repubblica 26 ottobre 1972, n. 633, che adottano sistemi evoluti di incasso, attraverso carte di debito e di credito e altre forme di pagamento elettronico, dei corrispettivi delle cessioni di beni e delle prestazioni di servizi di cui agli articoli 2 e 3 del citato decreto del Presidente della Repubblica n. 633 del 1972, che consentono la memorizzazione, l'inalterabilita' e la sicurezza dei dati, possono assolvere mediante tali sistemi all'obbligo di memorizzazione elettronica e di trasmissione telematica all'Agenzia delle entrate dei dati relativi ai corrispettivi giornalieri, di cui ai commi 1 e 2 del presente articolo. Con provvedimento del direttore dell'Agenzia delle entrate sono definiti le informazioni da trasmettere, le regole tecniche, i termini per la trasmissione telematica e le caratteristiche tecniche dei sistemi evoluti di incasso di cui al presente comma, idonei per l'assolvimento degli obblighi di memorizzazione e trasmissione dei dati.

6. COMMA ABROGATO DALLA L. 30 DICEMBRE 2020, N. 178.

6-bis. Al fine di contrastare l'evasione fiscale mediante l'incentivazione e la semplificazione delle operazioni telematiche, all'articolo 39, secondo comma, lettera a), alinea, del decreto del Presidente della Repubblica 26 ottobre 1972, n. 642, dopo le parole: 'nell'anno' sono inserite le seguenti: 'ovvero riscossi, dal 1º gennaio 2017, con modalita' telematiche, di cui all'articolo 3, comma 1, lettera a)'. Agli oneri derivanti dall'attuazione delle disposizioni di cui al presente comma, pari a 4 milioni di euro annui a decorrere dall'anno 2017, si fa fronte mediante corrispondente riduzione della dotazione finanziaria del Fondo di cui all'articolo 10, comma 5, del decreto-legge 29 novembre 2004, n. 282, convertito, con modificazioni, dalla legge 27 dicembre 2004, n. 307. Il Ministro dell'economia e delle finanze e' autorizzato ad apportare, con propri decreti, le occorrenti variazioni di bilancio.

6-ter. I dati relativi ai corrispettivi giornalieri di cui al comma 1 sono trasmessi telematicamente all'Agenzia delle entrate entro dodici giorni dall'effettuazione dell'operazione, determinata ai sensi dell'articolo 6 del decreto del Presidente della Repubblica 26 ottobre 1972, n. 633. Restano fermi gli obblighi di memorizzazione giornaliera dei dati relativi ai corrispettivi nonche' i termini di effettuazione delle liquidazioni periodiche dell'imposta sul valore aggiunto ai sensi dell'articolo 1, comma 1, del regolamento di cui al decreto del Presidente della Repubblica 23 marzo 1998, n. 100. Nel primo semestre di vigenza dell'obbligo di cui al comma 1, decorrente dal 1° luglio 2019 per i soggetti con volume di affari superiore a euro 400.000 e fino al 1° gennaio 2021 per gli altri soggetti, le sanzioni previste dagli articoli 6, comma 2-bis, 11, commi 2-quinquies, 5 e 5-bis, e 12, commi 2 e 3, del decreto legislativo 18 dicembre 1997, n. 471, non si applicano in caso di trasmissione telematica dei dati relativi ai corrispettivi giornalieri entro il mese successivo a quello di effettuazione dell'operazione, fermi restando i termini di liquidazione dell'imposta sul valore aggiunto.

6-quater. I soggetti tenuti all'invio dei dati al Sistema tessera sanitaria, ai fini dell'elaborazione della dichiarazione dei redditi precompilata, ai sensi dell'articolo 3, commi 3 e 4, del decreto legislativo 21 novembre 2014, n. 175, e dei relativi decreti del Ministro dell'economia e delle finanze, possono adempiere all'obbligo di cui al comma 1 mediante la memorizzazione elettronica e la trasmissione telematica dei dati, relativi a tutti i corrispettivi giornalieri, al Sistema tessera sanitaria. PERIODO SOPPRESSO DAL D.L. 18 OTTOBRE 2023, N. 145, CONVERTITO CON MODIFICAZIONI DALLA L. 15 DICEMBRE 2023, N. 191. I dati fiscali trasmessi al Sistema tessera sanitaria possono essere utilizzati solo dalle pubbliche amministrazioni per l'applicazione delle disposizioni in materia tributaria e doganale, ovvero in forma aggregata per il monitoraggio della spesa sanitaria pubblica e privata complessiva. Con decreto del Ministro dell'economia e delle finanze, di concerto con i Ministri della salute e per la pubblica amministrazione, sentito il Garante per la protezione dei dati personali, sono definiti, nel rispetto dei principi in materia di protezione dei dati personali, anche con riferimento agli obblighi di cui agli articoli 9 e 32 del regolamento (UE) 2016/679 del Parlamento europeo e del Consiglio, del 27 aprile 2016, i termini e gli ambiti di utilizzo dei predetti dati e i relativi limiti, anche temporali, nonche', ai sensi dell'articolo 2-sexies del codice di cui al decreto legislativo 30 giugno 2003, n. 196, i tipi di dati che possono essere trattati, le operazioni eseguibili, le misure appropriate e specifiche per tutelare i diritti e le liberta' dell'interessato.

6-quinquies. Negli anni 2019 e 2020 per l'acquisto o l'adattamento degli strumenti mediante i quali effettuare la memorizzazione e la trasmissione di cui al comma 1, al soggetto e' concesso un contributo complessivamente pari al 50 per cento della spesa sostenuta, per un massimo di euro 250 in caso di acquisto e di euro 50 in caso di adattamento, per ogni strumento. Al medesimo soggetto il contributo e' concesso sotto forma di credito d'imposta di pari importo, da utilizzare in compensazione ai sensi dell'articolo 17 del decreto legislativo 9 luglio 1997, n. 241. Al credito d'imposta di cui al presente comma non si applicano i limiti di cui all'articolo 1, comma 53, della legge 24 dicembre 2007, n. 244, e di cui all'articolo 34 della legge 23 dicembre 2000, n. 388, e il suo utilizzo e' consentito a decorrere dalla prima liquidazione periodica dell'imposta sul valore aggiunto successiva al mese in cui e' stata registrata la fattura relativa all'acquisto o all'adattamento degli strumenti mediante i quali effettuare la memorizzazione e la trasmissione di cui al comma 1 ed e' stato pagato, con modalita' tracciabile, il relativo corrispettivo. Con provvedimento del direttore dell'Agenzia delle entrate, da emanare entro trenta giorni dal 1° gennaio 2019, sono definiti le modalita' attuative, comprese le modalita' per usufruire del credito d'imposta, il regime dei controlli nonche' ogni altra disposizione necessaria per il monitoraggio dell'agevolazione e per il rispetto del limite di spesa previsto. Il limite di spesa previsto e' pari a euro 36,3 milioni per l'anno 2019 e pari ad euro 195,5 milioni per l'anno 2020.

--------------- AGGIORNAMENTO (3) La L. 27 dicembre 2017, n. 205 ha disposto (con l'art. 1, comma 916) che la presente modifica si applica alle fatture emesse a partire dal 1º gennaio 2019. Ha inoltre disposto (con l'art. 1, comma 917, lettere a) e b)) che "Fermo restando quanto previsto al comma 916, le disposizioni dei commi da 909 a 928 si applicano alle fatture emesse a partire dal 1º luglio 2018 relative a: a) cessioni di benzina o di gasolio destinati ad essere utilizzati come carburanti per motori; b) prestazioni rese da soggetti subappaltatori e subcontraenti della filiera delle imprese nel quadro di un contratto di appalto di lavori, servizi o forniture stipulato con un'amministrazione pubblica. Ai fini della presente lettera, per filiera delle imprese si intende l'insieme dei soggetti, destinatari della normativa di cui all'articolo 3 della legge 13 agosto 2010, n. 136, che intervengono a qualunque titolo nel ciclo di realizzazione del contratto, anche con noli e forniture di beni e prestazioni di servizi, ivi compresi quelli di natura intellettuale, qualunque sia l'importo dei relativi contratti o dei subcontratti. Le fatture elettroniche emesse ai sensi della presente lettera riportano gli stessi codici CUP e CIG di cui all'articolo 25, comma 2, del decreto-legge 24 aprile 2014, n. 66, convertito, con modificazioni, dalla legge 23 giugno 2014, n. 89, riportati nelle fatture emesse dall'impresa capofila nei confronti dell'amministrazione pubblica". --------------- AGGIORNAMENTO (4) L. 27 dicembre 2017, n. 205, come modificata dal D.L. 12 luglio 2018, n. 87, convertito con modificazioni dalla L. 9 agosto 2018, n. 96, ha disposto (con l'art. 1, comma 917, lettera a)) che "Fermo restando quanto previsto al comma 916, le disposizioni dei commi da 909 a 928 si applicano alle fatture emesse a partire dal 1º luglio 2018 relative a: a) cessioni di benzina o di gasolio destinati ad essere utilizzati come carburanti per motori, ad eccezione delle cessioni di carburante per autotrazione presso gli impianti stradali di distribuzione, per le quali il comma 920 si applica dal 1° gennaio 2019". --------------- AGGIORNAMENTO (24) La L. 30 dicembre 2024, n. 207, ha disposto (con l'art. 1, comma 77) che "Le disposizioni di cui ai commi da 74 a 76 si applicano a decorrere dal 1° gennaio 2026".

## Art. 3. - (Incentivi per la tracciabilita' dei pagamenti)

1. Il termine di decadenza di cui all'articolo 57, primo comma, del decreto del Presidente della Repubblica 26 ottobre 1972, n. 633, e il termine di decadenza di cui all'articolo 43, primo comma, del decreto del Presidente della Repubblica 29 settembre 1973, n. 600, sono ridotti di due anni. La riduzione si applica solo per i soggetti passivi di cui all'articolo 1 che garantiscono, nei modi stabiliti con decreto del Ministro dell'economia e delle finanze, la tracciabilita' dei pagamenti ricevuti ed effettuati relativi ad operazioni di ammontare superiore a euro 500. ((PERIODO ABROGATO DAL D.L. 23 OTTOBRE 2018, N. 119, CONVERTITO CON MODIFICAZIONI DALLA L. 17 DICEMBRE 2018, N. 136)). (3)(4)

--------------- AGGIORNAMENTO (3) La L. 27 dicembre 2017, n. 205 ha disposto (con l'art. 1, comma 916) che la presente modifica si applica alle fatture emesse a partire dal 1º gennaio 2019. Ha inoltre disposto (con l'art. 1, comma 917, lettere a) e b)) che "Fermo restando quanto previsto al comma 916, le disposizioni dei commi da 909 a 928 si applicano alle fatture emesse a partire dal 1º luglio 2018 relative a: a) cessioni di benzina o di gasolio destinati ad essere utilizzati come carburanti per motori; b) prestazioni rese da soggetti subappaltatori e subcontraenti della filiera delle imprese nel quadro di un contratto di appalto di lavori, servizi o forniture stipulato con un'amministrazione pubblica. Ai fini della presente lettera, per filiera delle imprese si intende l'insieme dei soggetti, destinatari della normativa di cui all'articolo 3 della legge 13 agosto 2010, n. 136, che intervengono a qualunque titolo nel ciclo di realizzazione del contratto, anche con noli e forniture di beni e prestazioni di servizi, ivi compresi quelli di natura intellettuale, qualunque sia l'importo dei relativi contratti o dei subcontratti. Le fatture elettroniche emesse ai sensi della presente lettera riportano gli stessi codici CUP e CIG di cui all'articolo 25, comma 2, del decreto-legge 24 aprile 2014, n. 66, convertito, con modificazioni, dalla legge 23 giugno 2014, n. 89, riportati nelle fatture emesse dall'impresa capofila nei confronti dell'amministrazione pubblica". --------------- AGGIORNAMENTO (4) L. 27 dicembre 2017, n. 205, come modificata dal D.L. 12 luglio 2018, n. 87, convertito con modificazioni dalla L. 9 agosto 2018, n. 96, ha disposto (con l'art. 1, comma 917, lettera a)) che "Fermo restando quanto previsto al comma 916, le disposizioni dei commi da 909 a 928 si applicano alle fatture emesse a partire dal 1º luglio 2018 relative a: a) cessioni di benzina o di gasolio destinati ad essere utilizzati come carburanti per motori, ad eccezione delle cessioni di carburante per autotrazione presso gli impianti stradali di distribuzione, per le quali il comma 920 si applica dal 1° gennaio 2019".

## Art. 4. - (Semplificazioni amministrative e contabili)

1. A partire dalle operazioni IVA effettuate dal 1° luglio 2021, in via sperimentale, nell'ambito di un programma di assistenza on line basato sui dati delle operazioni acquisiti con le fatture elettroniche e con le comunicazioni delle operazioni transfrontaliere nonche' sui dati dei corrispettivi acquisiti telematicamente e sugli ulteriori dati fiscali presenti nel sistema dell'Anagrafe tributaria, l'Agenzia delle entrate mette a disposizione di tutti i soggetti passivi dell'IVA residenti e stabiliti in Italia, in apposita area riservata del sito internet dell'Agenzia stessa, le bozze dei seguenti documenti:

- a) registri di cui agli articoli 23 e 25 del decreto del Presidente della Repubblica 26 ottobre 1972, n. 633;
- b) liquidazione periodica dell'IVA;
- c) LETTERA SOPPRESSA DAL D.L. 22 MARZO 2021, N. 41, CONVERTITO CON MODIFICAZIONI DALLA L. 21 MAGGIO 2021, N. 69. ((1.1)). A partire dalle operazioni IVA effettuate dal 1° gennaio 2022, in via sperimentale, oltre alle bozze dei documenti di cui al comma 1, lettere a) e b), l'Agenzia delle entrate mette a disposizione anche la bozza della dichiarazione annuale dell'IVA.

2. Per i soggetti passivi dell'IVA che, anche per il tramite di intermediari di cui all'articolo 3, comma 3, del regolamento di cui al decreto del Presidente della Repubblica 22 luglio 1998, n. 322, in possesso della delega per l'utilizzo dei servizi di fatturazione elettronica, convalidano, nel caso in cui le informazioni proposte dall'Agenzia delle entrate siano complete, ovvero integrano nel dettaglio i dati proposti nelle bozze dei documenti di cui al comma 1, lettera a), viene meno l'obbligo di tenuta dei registri di cui agli articoli 23 e 25 del decreto del Presidente della Repubblica 26 ottobre 1972, n. 633, fatta salva la tenuta del registro di cui all'articolo 18, comma 2, del decreto del Presidente della Repubblica 29 settembre 1973, n. 600. L'obbligo di tenuta dei registri ai fini dell'IVA permane per i soggetti che optano per la tenuta dei registri secondo le modalita' di cui all'articolo 18, comma 5, del decreto del Presidente della Repubblica 29 settembre 1973, n. 600. (5)

3. Con provvedimento del direttore dell'Agenzia delle entrate sono emanate le disposizioni necessarie per l'attuazione del presente articolo.

3-bis. L'Agenzia delle entrate mette a disposizione dei contribuenti residenti o stabiliti una piattaforma telematica dedicata alla compensazione di crediti e debiti derivanti da transazioni commerciali tra i suddetti soggetti, ad esclusione delle amministrazioni pubbliche individuate ai sensi dell'articolo 1, comma 2, della legge 31 dicembre 2009, n. 196, e risultanti da fatture elettroniche emesse ai sensi dell'articolo 1. La compensazione effettuata mediante piattaforma telematica produce i medesimi effetti dell'estinzione dell'obbligazione ai sensi della sezione III del capo IV del titolo I del libro quarto del codice civile, fino a concorrenza dello stesso valore e a condizione che per nessuna delle parti aderenti siano in corso procedure concorsuali o di ristrutturazione del debito omologate, ovvero piani attestati di risanamento iscritti presso il registro delle imprese. Nei confronti del debito originario insoluto si applicano comunque le disposizioni di cui al decreto legislativo 9 ottobre 2002, n. 231, in materia di ritardi di pagamento nelle transazioni commerciali.

--------------- AGGIORNAMENTO (3) La L. 27 dicembre 2017, n. 205 ha disposto (con l'art. 1, comma 916) che la presente modifica si applica alle fatture emesse a partire dal 1º gennaio 2019. Ha inoltre disposto (con l'art. 1, comma 917, lettere a) e b)) che "Fermo restando quanto previsto al comma 916, le disposizioni dei commi da 909 a 928 si applicano alle fatture emesse a partire dal 1º luglio 2018 relative a: a) cessioni di benzina o di gasolio destinati ad essere utilizzati come carburanti per motori; b) prestazioni rese da soggetti subappaltatori e subcontraenti della filiera delle imprese nel quadro di un contratto di appalto di lavori, servizi o forniture stipulato con un'amministrazione pubblica. Ai fini della presente lettera, per filiera delle imprese si intende l'insieme dei soggetti, destinatari della normativa di cui all'articolo 3 della legge 13 agosto 2010, n. 136, che intervengono a qualunque titolo nel ciclo di realizzazione del contratto, anche con noli e forniture di beni e prestazioni di servizi, ivi compresi quelli di natura intellettuale, qualunque sia l'importo dei relativi contratti o dei subcontratti. Le fatture elettroniche emesse ai sensi della presente lettera riportano gli stessi codici CUP e CIG di cui all'articolo 25, comma 2, del decreto-legge 24 aprile 2014, n. 66, convertito, con modificazioni, dalla legge 23 giugno 2014, n. 89, riportati nelle fatture emesse dall'impresa capofila nei confronti dell'amministrazione pubblica". --------------- AGGIORNAMENTO (4) L. 27 dicembre 2017, n. 205, come modificata dal D.L. 12 luglio 2018, n. 87, convertito con modificazioni dalla L. 9 agosto 2018, n. 96, ha disposto (con l'art. 1, comma 917, lettera a)) che "Fermo restando quanto previsto al comma 916, le disposizioni dei commi da 909 a 928 si applicano alle fatture emesse a partire dal 1º luglio 2018 relative a: a) cessioni di benzina o di gasolio destinati ad essere utilizzati come carburanti per motori, ad eccezione delle cessioni di carburante per autotrazione presso gli impianti stradali di distribuzione, per le quali il comma 920 si applica dal 1° gennaio 2019". -------------- AGGIORNAMENTO (5) Il D.L. 23 ottobre 2018, n. 119, convertito con modificazioni, dalla L. 17 dicembre 2018, n. 136, ha disposto (con l'art. 17, comma 2, lettera b)) che "A decorrere dal 1° gennaio 2020: [...] b) all'articolo 4, del decreto legislativo 5 agosto 2015, n. 127, sono apportate le seguenti modificazioni: 1. al comma 1, le parole «compresi coloro che hanno esercitato l'opzione di cui all'articolo 2, comma 1,» sono soppresse; 2. al comma 2, dopo le parole «n. 633» sono aggiunte le seguenti: «, fatta salva la tenuta del registro di cui all'articolo 18, comma 2, del decreto del Presidente della Repubblica 29 settembre 1973, n. 600. L'obbligo di tenuta dei registri ai fini dell'imposta sul valore aggiunto permane per i soggetti che optano per la tenuta dei registri secondo le modalita' di cui all'articolo 18, comma 5 del decreto del Presidente della Repubblica 29 settembre 1973, n. 600.»".

## Art. 5.

ARTICOLO ABROGATO DALLA L. 27 DICEMBRE 2017, N. 205 (3) ((4))

--------------- AGGIORNAMENTO (3) La L. 27 dicembre 2017, n. 205 ha disposto (con l'art. 1, comma 916) che la presente modifica si applica alle fatture emesse a partire dal 1º gennaio 2019. Ha inoltre disposto (con l'art. 1, comma 917, lettere a) e b)) che "Fermo restando quanto previsto al comma 916, le disposizioni dei commi da 909 a 928 si applicano alle fatture emesse a partire dal 1º luglio 2018 relative a: a) cessioni di benzina o di gasolio destinati ad essere utilizzati come carburanti per motori; b) prestazioni rese da soggetti subappaltatori e subcontraenti della filiera delle imprese nel quadro di un contratto di appalto di lavori, servizi o forniture stipulato con un'amministrazione pubblica. Ai fini della presente lettera, per filiera delle imprese si intende l'insieme dei soggetti, destinatari della normativa di cui all'articolo 3 della legge 13 agosto 2010, n. 136, che intervengono a qualunque titolo nel ciclo di realizzazione del contratto, anche con noli e forniture di beni e prestazioni di servizi, ivi compresi quelli di natura intellettuale, qualunque sia l'importo dei relativi contratti o dei subcontratti. Le fatture elettroniche emesse ai sensi della presente lettera riportano gli stessi codici CUP e CIG di cui all'articolo 25, comma 2, del decreto-legge 24 aprile 2014, n. 66, convertito, con modificazioni, dalla legge 23 giugno 2014, n. 89, riportati nelle fatture emesse dall'impresa capofila nei confronti dell'amministrazione pubblica". --------------- AGGIORNAMENTO (4) L. 27 dicembre 2017, n. 205, come modificata dal D.L. 12 luglio 2018, n. 87, convertito con modificazioni dalla L. 9 agosto 2018, n. 96, ha disposto (con l'art. 1, comma 917, lettera a)) che "Fermo restando quanto previsto al comma 916, le disposizioni dei commi da 909 a 928 si applicano alle fatture emesse a partire dal 1º luglio 2018 relative a: a) cessioni di benzina o di gasolio destinati ad essere utilizzati come carburanti per motori, ad eccezione delle cessioni di carburante per autotrazione presso gli impianti stradali di distribuzione, per le quali il comma 920 si applica dal 1° gennaio 2019".

## Art. 6. - Disposizione finanziaria

1. Agli oneri derivanti dall'articolo 1, commi 1 e 2, pari a 9,34 milioni di euro per l'anno 2016, a 18,00 milioni di euro per l'anno 2017 e a 20,40 milioni di euro a decorrere dall'anno 2018, si provvede mediante corrispondente riduzione della dotazione del fondo di cui all'articolo 16, comma 1, ultimo periodo, della legge 11 marzo 2014, n. 23. Il Ministro dell'economia e delle finanze e' autorizzato ad apportare, con propri decreti, le occorrenti variazioni di bilancio.

## Art. 7. - Abrogazioni

1. A decorrere dal 1° gennaio 2017 sono abrogati i commi da 429 a 432 dell'articolo 1, della legge 30 dicembre 2004, n. 311. Per le imprese che operano nel settore della grande distribuzione l'opzione di cui all'articolo 1, commi da 429 a 432, della legge 30 dicembre 2004, n. 311, gia' esercitata entro il 31 dicembre 2016, resta valida fino al 31 dicembre 2018. (3) ((4))

--------------- AGGIORNAMENTO (3) La L. 27 dicembre 2017, n. 205 ha disposto (con l'art. 1, comma 916) che la presente modifica si applica alle fatture emesse a partire dal 1º gennaio 2019. Ha inoltre disposto (con l'art. 1, comma 917, lettere a) e b)) che "Fermo restando quanto previsto al comma 916, le disposizioni dei commi da 909 a 928 si applicano alle fatture emesse a partire dal 1º luglio 2018 relative a: a) cessioni di benzina o di gasolio destinati ad essere utilizzati come carburanti per motori; b) prestazioni rese da soggetti subappaltatori e subcontraenti della filiera delle imprese nel quadro di un contratto di appalto di lavori, servizi o forniture stipulato con un'amministrazione pubblica. Ai fini della presente lettera, per filiera delle imprese si intende l'insieme dei soggetti, destinatari della normativa di cui all'articolo 3 della legge 13 agosto 2010, n. 136, che intervengono a qualunque titolo nel ciclo di realizzazione del contratto, anche con noli e forniture di beni e prestazioni di servizi, ivi compresi quelli di natura intellettuale, qualunque sia l'importo dei relativi contratti o dei subcontratti. Le fatture elettroniche emesse ai sensi della presente lettera riportano gli stessi codici CUP e CIG di cui all'articolo 25, comma 2, del decreto-legge 24 aprile 2014, n. 66, convertito, con modificazioni, dalla legge 23 giugno 2014, n. 89, riportati nelle fatture emesse dall'impresa capofila nei confronti dell'amministrazione pubblica". --------------- AGGIORNAMENTO (4) L. 27 dicembre 2017, n. 205, come modificata dal D.L. 12 luglio 2018, n. 87, convertito con modificazioni dalla L. 9 agosto 2018, n. 96, ha disposto (con l'art. 1, comma 917, lettera a)) che "Fermo restando quanto previsto al comma 916, le disposizioni dei commi da 909 a 928 si applicano alle fatture emesse a partire dal 1º luglio 2018 relative a: a) cessioni di benzina o di gasolio destinati ad essere utilizzati come carburanti per motori, ad eccezione delle cessioni di carburante per autotrazione presso gli impianti stradali di distribuzione, per le quali il comma 920 si applica dal 1° gennaio 2019".

